@@ -1,3 +1,4 @@
+# frozen_string_literal: false
 # = net/pop.rb
 #
 # Copyright (c) 1999-2007 Yukihiro Matsumoto.
@@ -13,9 +14,9 @@
 # Ruby Distribute License.
 #
 # NOTE: You can find Japanese version of this document at:
-# http://www.ruby-lang.org/ja/man/html/net_pop.html
+# http://docs.ruby-lang.org/ja/latest/library/net=2fpop.html
 #
-#   $Id: pop.rb 31728 2011-05-25 00:30:04Z drbrain $
+#   $Id: pop.rb 56865 2016-11-21 23:05:41Z normal $
 #
 # See Net::POP3 for documentation.
 #
@@ -41,8 +42,6 @@ module Net
   # Unexpected response from the server.
   class POPBadResponse < POPError; end
 
-  #
-  # = Net::POP3
   #
   # == What is This Library?
   #
@@ -197,7 +196,7 @@ module Net
   class POP3 < Protocol
 
     # svn revision of this library
-    Revision = %q$Revision: 31728 $.split[1]
+    Revision = %q$Revision: 56865 $.split[1]
 
     #
     # Class Parameters
@@ -326,7 +325,7 @@ module Net
 
     @ssl_params = nil
 
-    # call-seq:
+    # :call-seq:
     #    Net::POP.enable_ssl(params = {})
     #
     # Enable SSL for all new instances.
@@ -375,7 +374,7 @@ module Net
       return @ssl_params[:verify_mode]
     end
 
-    # returns the :ca_file or :ca_path from POP3.ssh_params
+    # returns the :ca_file or :ca_path from POP3.ssl_params
     def POP3.certs
       return @ssl_params[:ca_file] || @ssl_params[:ca_path]
     end
@@ -444,7 +443,7 @@ module Net
       return !@ssl_params.nil?
     end
 
-    # call-seq:
+    # :call-seq:
     #    Net::POP#enable_ssl(params = {})
     #
     # Enables SSL for this instance.  Must be called before the connection is
@@ -498,12 +497,12 @@ module Net
 
     # Seconds to wait until a connection is opened.
     # If the POP3 object cannot open a connection within this time,
-    # it raises a TimeoutError exception.
+    # it raises a Net::OpenTimeout exception. The default value is 30 seconds.
     attr_accessor :open_timeout
 
     # Seconds to wait until reading one block (by one read(1) call).
     # If the POP3 object cannot complete a read() within this time,
-    # it raises a TimeoutError exception.
+    # it raises a Net::ReadTimeout exception. The default value is 60 seconds.
     attr_reader :read_timeout
 
     # Set the read timeout.
@@ -542,7 +541,9 @@ module Net
 
     # internal method for Net::POP3.start
     def do_start(account, password) # :nodoc:
-      s = timeout(@open_timeout) { TCPSocket.open(@address, port) }
+      s = Timeout.timeout(@open_timeout, Net::OpenTimeout) do
+        TCPSocket.open(@address, port)
+      end
       if use_ssl?
         raise 'openssl library not installed' unless defined?(OpenSSL)
         context = OpenSSL::SSL::SSLContext.new
@@ -554,10 +555,10 @@ module Net
           s.post_connection_check(@address)
         end
       end
-      @socket = InternetMessageIO.new(s)
+      @socket = InternetMessageIO.new(s,
+                                      read_timeout: @read_timeout,
+                                      debug_output: @debug_output)
       logging "POP session started: #{@address}:#{@port} (#{@apop ? 'APOP' : 'POP'})"
-      @socket.read_timeout = @read_timeout
-      @socket.debug_output = @debug_output
       on_connect
       @command = POP3Command.new(@socket)
       if apop?
@@ -569,7 +570,7 @@ module Net
     ensure
       # Authentication failed, clean up connection.
       unless @started
-        s.close if s and not s.closed?
+        s.close if s
         @socket = nil
         @command = nil
       end
@@ -600,7 +601,7 @@ module Net
     ensure
       @started = false
       @command = nil
-      @socket.close if @socket and not @socket.closed?
+      @socket.close if @socket
       @socket = nil
     end
     private :do_finish
@@ -707,7 +708,7 @@ module Net
       @mails.each {|m| m.uid = uidl[m.number] }
     end
 
-    # deguging output for +msg+
+    # debugging output for +msg+
     def logging(msg)
       @debug_output << msg + "\n" if @debug_output
     end
@@ -715,9 +716,9 @@ module Net
   end   # class POP3
 
   # class aliases
-  POP = POP3
-  POPSession  = POP3
-  POP3Session = POP3
+  POP = POP3 # :nodoc:
+  POPSession  = POP3 # :nodoc:
+  POP3Session = POP3 # :nodoc:
 
   #
   # This class is equivalent to POP3, except that it uses APOP authentication.
@@ -889,7 +890,7 @@ module Net
 
     def initialize(sock)
       @socket = sock
-      @error_occured = false
+      @error_occurred = false
       res = check_response(critical { recv_response() })
       @apop_stamp = res.slice(/<[!-~]+@[!-~]+>/)
     end
@@ -1007,11 +1008,11 @@ module Net
     end
 
     def critical
-      return '+OK dummy ok response' if @error_occured
+      return '+OK dummy ok response' if @error_occurred
       begin
         return yield()
       rescue Exception
-        @error_occured = true
+        @error_occurred = true
         raise
       end
     end
