@@ -1,13 +1,18 @@
+# frozen_string_literal: false
 require 'rss/1.0'
 require 'rss/dublincore'
 
 module RSS
 
+  # The prefix for the Image XML namespace.
   IMAGE_PREFIX = 'image'
-  IMAGE_URI = 'http://web.resource.org/rss/1.0/modules/image/'
+  # The URI for the Image specification.
+  IMAGE_URI = 'http://purl.org/rss/1.0/modules/image/'
 
   RDF.install_ns(IMAGE_PREFIX, IMAGE_URI)
 
+  # This constant holds strings which contain the names of
+  # image elements, with the appropriate prefix.
   IMAGE_ELEMENTS = []
 
   %w(item favicon).each do |name|
@@ -15,7 +20,7 @@ module RSS
     BaseListener.install_class_name(IMAGE_URI, name, "Image#{class_name}")
     IMAGE_ELEMENTS << "#{IMAGE_PREFIX}_#{name}"
   end
-  
+
   module ImageModelUtils
     def validate_one_tag_name(ignore_unknown_element, name, tags)
       if !ignore_unknown_element
@@ -25,7 +30,7 @@ module RSS
       raise TooMuchTagError.new(name, tag_name) if tags.size > 1
     end
   end
-  
+
   module ImageItemModel
     include ImageModelUtils
     extend BaseModel
@@ -43,12 +48,12 @@ module RSS
       include DublinCoreModel
 
       @tag_name = "item"
-      
+
       class << self
         def required_prefix
           IMAGE_PREFIX
         end
-        
+
         def required_uri
           IMAGE_URI
         end
@@ -69,7 +74,7 @@ module RSS
         disp_name = "#{IMAGE_PREFIX}:#{tag}"
         install_text_element(tag, IMAGE_URI, "?",
                              full_name, :integer, disp_name)
-        BaseListener.install_get_text_element(IMAGE_URI, tag, "#{full_name}=")
+        BaseListener.install_get_text_element(IMAGE_URI, tag, full_name)
       end
 
       alias width= image_width=
@@ -102,11 +107,11 @@ module RSS
       end
     end
   end
-  
+
   module ImageFaviconModel
     include ImageModelUtils
     extend BaseModel
-    
+
     def self.append_features(klass)
       super
 
@@ -122,12 +127,12 @@ module RSS
       include DublinCoreModel
 
       @tag_name = "favicon"
-      
+
       class << self
         def required_prefix
           IMAGE_PREFIX
         end
-        
+
         def required_uri
           IMAGE_URI
         end
@@ -142,8 +147,8 @@ module RSS
       end
 
       AVAILABLE_SIZES = %w(small medium large)
-      alias_method :_size=, :size=
-      private :_size=
+      alias_method :set_size, :size=
+      private :set_size
       def size=(new_value)
         if @do_validate and !new_value.nil?
           new_value = new_value.strip
@@ -152,9 +157,9 @@ module RSS
             raise NotAvailableValueError.new(full_name, new_value, attr_name)
           end
         end
-        __send__(:_size=, new_value)
+        set_size(new_value)
       end
-      
+
       alias image_size= size=
       alias image_size size
 
