@@ -2,7 +2,7 @@
 #
 # tempfile - manipulates temporary files
 #
-# $Id: tempfile.rb 53141 2015-12-16 05:07:31Z naruse $
+# $Id: tempfile.rb 58013 2017-03-18 12:02:27Z naruse $
 #
 
 require 'delegate'
@@ -80,7 +80,7 @@ require 'tmpdir'
 # mutex.
 class Tempfile < DelegateClass(File)
   # call-seq:
-  #    new(basename, [tmpdir = Dir.tmpdir], [options])
+  #    new(basename = "", [tmpdir = Dir.tmpdir], [options])
   #
   # Creates a temporary file with permissions 0600 (= only readable and
   # writable by the owner) and opens it with mode "w+".
@@ -147,7 +147,7 @@ class Tempfile < DelegateClass(File)
   end
 
   def _close    # :nodoc:
-    @tmpfile.close unless @tmpfile.closed?
+    @tmpfile.close
   end
   protected :_close
 
@@ -227,7 +227,7 @@ class Tempfile < DelegateClass(File)
     if !@tmpfile.closed?
       @tmpfile.size # File#size calls rb_io_flush_raw()
     else
-      File.size?(@tmpfile.path)
+      File.size(@tmpfile.path)
     end
   end
   alias length size
@@ -252,7 +252,7 @@ class Tempfile < DelegateClass(File)
 
       warn "removing #{@tmpfile.path}..." if $DEBUG
 
-      @tmpfile.close unless @tmpfile.closed?
+      @tmpfile.close
       begin
         File.unlink(@tmpfile.path)
       rescue Errno::ENOENT
@@ -323,7 +323,7 @@ end
 #      ... do something with f ...
 #   end
 #
-def Tempfile.create(basename, tmpdir=nil, mode: 0, **options)
+def Tempfile.create(basename="", tmpdir=nil, mode: 0, **options)
   tmpfile = nil
   Dir::Tmpname.create(basename, tmpdir, options) do |tmpname, n, opts|
     mode |= File::RDWR|File::CREAT|File::EXCL
@@ -334,7 +334,7 @@ def Tempfile.create(basename, tmpdir=nil, mode: 0, **options)
     begin
       yield tmpfile
     ensure
-      tmpfile.close if !tmpfile.closed?
+      tmpfile.close
       File.unlink tmpfile
     end
   else
